import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:tencent_cloud_chat_customer_service_plugin/common/utils.dart';
import 'package:tencent_cloud_chat_customer_service_plugin/components/message-branch.dart';
import 'package:tencent_cloud_chat_customer_service_plugin/components/message-formSave/message-formSave.dart';
import 'package:tencent_cloud_chat_customer_service_plugin/components/message-productCard.dart';
import 'package:tencent_cloud_chat_customer_service_plugin/components/message-rating/message-rating.dart';
import 'package:tencent_im_base/tencent_im_base.dart';

class MessageCustomerService extends StatefulWidget {
  final TUITheme theme;
  final V2TimMessage message;
  final bool isShowJumpState;
  final EdgeInsetsGeometry? textPadding;
  final Color? messageBackgroundColor;
  final BorderRadius? messageBorderRadius;
  final Function sendMessage;
  MessageCustomerService(
      {super.key,
      required this.theme,
      required this.message,
      this.isShowJumpState = false,
      required this.sendMessage,
      this.textPadding,
      this.messageBackgroundColor,
      this.messageBorderRadius});

  @override
  State<StatefulWidget> createState() => _MessageCustomerServiceState();
}

class _MessageCustomerServiceState extends State<MessageCustomerService> {
  @override
  Widget build(BuildContext context) {
    var messageSrc;
    var payload;
    Map<String, dynamic> mapData = {};
    V2TimCustomElem? custom = widget.message.customElem;

    final isFromSelf = widget.message.isSelf ?? true;
    final borderRadius = isFromSelf
        ? const BorderRadius.only(
            topLeft: Radius.circular(10),
            topRight: Radius.circular(2),
            bottomLeft: Radius.circular(10),
            bottomRight: Radius.circular(10))
        : const BorderRadius.only(
            topLeft: Radius.circular(2),
            topRight: Radius.circular(10),
            bottomLeft: Radius.circular(10),
            bottomRight: Radius.circular(10));

    final defaultStyle = isFromSelf
        ? widget.theme.lightPrimaryMaterialColor.shade50
        : widget.theme.weakBackgroundColor;
    final backgroundColor = widget.isShowJumpState
        ? const Color.fromRGBO(245, 166, 35, 1)
        : defaultStyle;

    if (custom != null) {
      String? data = custom.data;
      if (data != null && data.isNotEmpty) {
        try {
          mapData = json.decode(data);
          messageSrc = mapData["src"];
        } catch (err) {
          // err
        }
      }
    }
    switch (messageSrc) {
      case CUSTOM_MESSAGE_SRC.MENU:
        try {
          payload = mapData["menuContent"];
        } catch (err) {
          // err
          print(err);
        }
        return Container(
            padding: (widget.textPadding ?? const EdgeInsets.all(10)),
            child: MessageRating(
              payload: payload,
              onSubmitRating: widget.sendMessage,
            ));
      case CUSTOM_MESSAGE_SRC.FROM_INPUT:
        try {
          payload = mapData["content"];
        } catch (err) {
          // err
          print(err);
        }
        return Container(
            padding: (widget.textPadding ?? const EdgeInsets.all(10)),
            decoration: BoxDecoration(
              color: widget.messageBackgroundColor ?? backgroundColor,
              borderRadius: widget.messageBorderRadius ?? borderRadius,
            ),
            child: MessageFormSave(
              payload: payload,
              onSubmitForm: widget.sendMessage,
            ));
      case CUSTOM_MESSAGE_SRC.PRODUCT_CARD:
        try {
          payload = mapData["content"];
        } catch (err) {
          // err
          print(err);
        }
        return Container(
            padding: (widget.textPadding ?? const EdgeInsets.all(10)),
            decoration: BoxDecoration(
              color: Colors.white,
              border: Border.all(color: Colors.grey, width: 0.5),
              borderRadius: widget.messageBorderRadius ?? borderRadius,
            ),
            child: MessageProductCard(payload: payload));
      case CUSTOM_MESSAGE_SRC.BRANCH:
        try {
          payload = mapData["content"];
        } catch (err) {
          // err
          print(err);
        }
        return Container(
            padding: (widget.textPadding ?? const EdgeInsets.all(10)),
            decoration: BoxDecoration(
              color: widget.messageBackgroundColor ?? backgroundColor,
              borderRadius: widget.messageBorderRadius ?? borderRadius,
            ),
            child: MessageBranch(
              payload: payload,
              onClickItem: widget.sendMessage,
            ));
    }

    return Container();
  }
}
