import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:tencent_im_base/tencent_im_base.dart';

class FormSaveInput extends StatefulWidget {
  final dynamic payload;
  final Function onSubmitInput;
  const FormSaveInput(
      {super.key, required this.payload, required this.onSubmitInput});

  @override
  State<StatefulWidget> createState() => _FormSaveInputState();
}

class _FormSaveInputState extends TIMState<FormSaveInput> {
  TextEditingController _inputController = TextEditingController();
  bool hasReply = false;
  Future<V2TimMsgCreateInfoResult?> clickItem({required String text}) async {
    final res = await TencentImSDKPlugin.v2TIMManager
        .getMessageManager()
        .createTextMessage(text: text);
    if (res.code == 0) {
      final messageResult = res.data;
      V2TimMessage? messageInfo = messageResult!.messageInfo;
      if (!kIsWeb && (Platform.isMacOS || Platform.isWindows)) {
        messageInfo?.id = messageResult.id;
      }
      widget.onSubmitInput(messageInfo: messageInfo);
      return messageResult;
    }
    return null;
  }

  Widget timBuild(BuildContext context) {
    final header = widget.payload['header'] ?? "";

    try {
      if (widget.payload['selected'] != null) {
        if (widget.payload['selected']['content'] != null) {
          hasReply = true;
          _inputController.text = widget.payload['selected']['content'];
          print(hasReply);
        }
      }
    } catch (e) {}
    return Container(
      constraints: BoxConstraints(maxWidth: 250),
      child: Column(mainAxisAlignment: MainAxisAlignment.start, children: [
        Padding(
          padding: const EdgeInsets.fromLTRB(0, 0, 0, 5),
          child: Text(header),
        ),
        Row(
          children: [
            Expanded(
                child: Container(
              constraints: BoxConstraints(maxHeight: 36),
              decoration: BoxDecoration(
                  color: Colors.white,
                  border: Border.all(color: Colors.grey, width: 0.5),
                  borderRadius:
                      BorderRadius.horizontal(left: Radius.circular(10))),
              child: TextField(
                decoration: InputDecoration(
                  border: const OutlineInputBorder(borderSide: BorderSide.none),
                  contentPadding: const EdgeInsets.all(0),
                ),
                controller: _inputController,
              ),
            )),
            Expanded(
                flex: 0,
                child: Container(
                  constraints: BoxConstraints(maxHeight: 36),
                  decoration: BoxDecoration(
                      color: hasReply ? Colors.grey : Colors.blue,
                      border: Border.all(color: Colors.grey, width: 0.5),
                      borderRadius:
                          BorderRadius.horizontal(right: Radius.circular(10))),
                  child: IconButton(
                    padding: const EdgeInsets.fromLTRB(8, 5, 8, 8),
                    icon: Icon(
                      Icons.keyboard_arrow_right,
                      color: Colors.white,
                    ),
                    onPressed: () {
                      print(hasReply);
                      if (hasReply) {
                        return;
                      }
                      setState(() {
                        hasReply = true;
                      });
                      clickItem(text: _inputController.text);
                    },
                  ),
                ))
          ],
        )
      ]),
    );
  }
}
